convert abstract method
Adds input to the sequence of converted bytes and finishes converting
all bytes.
If expectedMac is non-null, then the method will throw
SecretBoxAuthenticationError if the computed MAC does match.
If possibleBuffer is non-null, the method is allowed (but not required)
to write the output to it. The buffer can be the same as input.
Otherwise the method will allocate memory for the output.
Implementation
Future<List<int>> convert(
List<int> input, {
required Mac? expectedMac,
Uint8List? possibleBuffer,
});