DartChacha20State class

State for DartChacha20.

Inheritance

Constructors

DartChacha20State({required Cipher cipher})

Properties

block → Uint8List
latefinal
blockAsUint32List → Uint32List
final
cipher → Cipher
The cipher used by this state.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
keyStreamIndex ↔ int
getter/setter pairinherited
mac → Mac
MAC.
no setterinherited
macSink → MacSink
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

beforeClose() → List<int>
Called before close.
inherited
beforeData({required SecretKeyData secretKey, required List<int> nonce, List<int> aad = const []}) → void
Called before data is added.
override
convert(List<int> input, {Uint8List? possibleBuffer, Mac? expectedMac, int? chunkSize}) → Future<List<int>>
Adds input to the sequence of converted bytes and finishes converting all bytes.
inherited
convertChunkSync(List<int> input, {Uint8List? possibleBuffer}) → List<int>
Adds input to the sequence of converted bytes. Returns a list of converted bytes, which may be empty or larger the input.
inherited
convertSync(List<int> input, {Uint8List? possibleBuffer, Mac? expectedMac}) → List<int>
inherited
deriveKeySync({required SecretKeyData secretKey, required List<int> nonce}) → SecretKeyData
inherited
deriveNonce({required SecretKeyData secretKey, required List<int> nonce}) → List<int>
inherited
initialize({required bool isEncrypting, required SecretKey secretKey, required List<int> nonce, List<int> aad = const [], int keyStreamIndex = 0}) → Future<void>
Initializes the state with the given secretKey, nonce, and aad.
inherited
initializeSync({required bool isEncrypting, required SecretKey secretKey, required List<int> nonce, List<int> aad = const [], int keyStreamIndex = 0}) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setBlock(int blockIndex) → void
Fills block with a new key stream block.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited