DelegatingEcdsa class abstract

Delegating base class for Ecdsa implementations.

Inheritance
Implemented types

Constructors

DelegatingEcdsa()
const

Properties

fallback → Ecdsa
no setteroverride
hashAlgorithm → HashAlgorithm
Used hash algorithm.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
keyPairType → KeyPairType<KeyPairData, PublicKey>
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

newKeyPair() → Future<EcKeyPair>
Generates a new KeyPair for this algorithm.
override
newKeyPairFromSeed(List<int> seed) → Future<EcKeyPair>
Generates a new KeyPair that uses the seed bytes.
override
newSignatureWand() → Future<SignatureWand>
Generates a new SignatureWand that has a random KeyPair.
inherited
newSignatureWandFromKeyPair(KeyPair keyPair) → Future<SignatureWand>
Generates a new SignatureWand that uses the given KeyPair.
inherited
newSignatureWandFromSeed(List<int> seed) → Future<SignatureWand>
Generates a new SignatureWand that uses the given seed bytes.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sign(List<int> message, {required KeyPair keyPair}) → Future<Signature>
Signs bytes.
inherited
signString(String message, {required KeyPair keyPair}) → Future<Signature>
Signs a string.
inherited
toString() → String
A string representation of this object.
inherited
verify(List<int> message, {required Signature signature}) → Future<bool>
Verifies whether bytes was signed with signature.
inherited
verifyString(String message, {required Signature signature}) → Future<bool>
Verifies whether a string was signed with signature.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited