DelegatingRsaPss class abstract

Delegating base class for RsaPss implementations.

Inheritance
Implemented types

Constructors

DelegatingRsaPss()
const

Properties

fallback → RsaPss
no setteroverride
hashAlgorithm → HashAlgorithm
Hash algorithm used by the RSA-PSS.
no setteroverride
hashCode → int
The hash code for this object.
no setterinherited
keyPairType → KeyPairType<KeyPairData, PublicKey>
no setterinherited
nonceLengthInBytes → int
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

newKeyPair({int modulusLength = RsaPss.defaultModulusLength, List<int> publicExponent = RsaPss.defaultPublicExponent}) → Future<RsaKeyPair>
Generates a new KeyPair for this algorithm.
override
newKeyPairFromSeed(List<int> seed) → Future<KeyPair>
Generates a new KeyPair that uses the seed bytes.
inherited
newSignatureWand() → Future<SignatureWand>
Generates a new SignatureWand that has a random KeyPair.
inherited
newSignatureWandFromKeyPair(KeyPair keyPair) → Future<SignatureWand>
Generates a new SignatureWand that uses the given KeyPair.
inherited
newSignatureWandFromSeed(List<int> seed) → Future<SignatureWand>
Generates a new SignatureWand that uses the given seed bytes.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sign(List<int> message, {required KeyPair keyPair}) → Future<Signature>
Signs bytes.
inherited
signString(String message, {required KeyPair keyPair}) → Future<Signature>
Signs a string.
inherited
toString() → String
A string representation of this object.
inherited
verify(List<int> message, {required Signature signature}) → Future<bool>
Verifies whether bytes was signed with signature.
inherited
verifyString(String message, {required Signature signature}) → Future<bool>
Verifies whether a string was signed with signature.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited